.. code-block:: bash

   Usage: nessie content commit [OPTIONS] KEY...

     Commit content.

         KEY is the content key that is associated with a specific content to
         commit. This accepts as well multiple keys with space in between. The key
         can be in this format: 'table.key' or 'namespace."table.key"'.

     Examples:

         nessie content commit -m "my awesome commit message" -r dev -c 122345abcd
         my_table -> Commit to branch 'dev' on expected hash '122345abcd' (head of
         the branch) the content from the interactive editor with the commit
         message "my awesome commit message" for content "my_table".

         nessie content commit -i -r dev -c 122345abcd my_table -> Commit to branch
         'dev' on expected hash '122345abcd' (head of the branch) the content from
         STDIN with the commit message from the interactive editor for content
         "my_table".

         nessie content commit -m "my awesome commit message" -R -r dev -c
         122345abcd my_table_1 my_table_2 -> Delete contents "my_table_1" and
         "my_table_2" from branch 'dev' on expected hash '122345abcd' and commit to
         branch 'dev" with the commit message "my awesome commit message".

   Options:
     -r, --ref TEXT             Branch to commit content to. If not supplied the
                                default branch from config is used.
     -i, --stdin                Read content for --set from STDIN (separated by
                                Ctrl-D)
     -s, --expect-same-content  Send the same content both as the new and expected
                                (old contents) parameters for the edit operations
     -c, --condition TEXT       Expected hash. Only perform the action if the
                                branch currently points to the hash specified by
                                this option.  [required]
     -R, --remove-key           Delete a content.
     -m, --message TEXT         Commit message.
     --author TEXT              The author to use for the commit
     --help                     Show this message and exit.


